// Copyright 2023 The ostui Authors
// SPDX-License-Identifier: GPL-3.0-only

package main

import (
	"time"

	"github.com/rivo/tview"
)

// LogPage is a TUI element that shows log messages
type LogPage struct {
	Root *tview.Flex

	logList *tview.List

	// external refs
	ui *UI
}

func (ui *UI) createLogPage() *LogPage {
	logPage := LogPage{
		ui: ui,
	}

	logPage.logList = tview.NewList().ShowSecondaryText(false)

	logPage.Root = tview.NewFlex().
		SetDirection(tview.FlexRow).
		AddItem(logPage.logList, 0, 1, true)

	return &logPage
}

// Print writes a message to the log
func (l *LogPage) Print(line string) {
	l.ui.app.QueueUpdateDraw(func() {
		line := time.Now().Local().Format("(15:04:05) ") + line
		l.logList.InsertItem(0, line, "", 0, nil)

		// Make sure the log list doesn't grow infinitely
		toRemove := l.logList.GetItemCount() - 100
		for c := 0; c < toRemove; c++ {
			l.logList.RemoveItem(-1)
		}
	})
}
